@@ -13,7 +13,6 @@ import time
 import warnings
 from collections import defaultdict
 
-import six
 import requests
 
 try:
@@ -39,10 +38,10 @@ from copr_cli.util import get_progress_callback, serializable, package_version
 from .build_config import MockProfile
 
 
-if six.PY2:
-    from urlparse import urljoin, urlparse
-else:
+try:
     from urllib.parse import urljoin, urlparse
+except ImportError:
+    from urlparse import urljoin, urlparse
 
 log = logging.getLogger(__name__)
 
@@ -669,7 +668,10 @@ class Commands(object):
                     "-A", "review.json",
                     "-A", "rpmlint.txt",
                 ])
-                cmd.append(chroot.result_url + "fedora-review")
+                # fedora-review url redirects to the fedora-review/ and wget2 with -A option
+                # doesn't follow redirects in this case
+                # upstream issue: https://bugzilla.redhat.com/show_bug.cgi?id=2348400
+                cmd.append(chroot.result_url + "fedora-review/")
 
             cmd.append(chroot.result_url)
             subprocess.call(cmd)
